@@ -1,5 +1,6 @@
 import json
 import math
+from collections import OrderedDict
 from logging import getLogger
 from typing import Any, Optional, List, Dict, Generator
 
@@ -398,11 +399,18 @@ class VectorStoreWrapperBase(BaseToolApiWrapper):
             
         # Initialize document map for tracking by ID
         doc_map = {
-            f"{doc.metadata.get('id', f'idx_{i}')}_{doc.metadata['chunk_id']}"
-            if 'chunk_id' in doc.metadata
-            else doc.metadata.get('id', f"idx_{i}"): (doc, score)
+            (
+                f"{doc.metadata.get('id', f'idx_{i}')}_{doc.metadata['chunk_id']}"
+                if 'chunk_id' in doc.metadata
+                else doc.metadata.get('id', f"idx_{i}")
+            ): (doc, 1 - score)
             for i, (doc, score) in enumerate(vector_items)
         }
+
+        # Sort the items by the new score in descending order
+        doc_map = OrderedDict(
+            sorted(doc_map.items(), key=lambda x: x[1][1], reverse=True)
+        )
         
         # Process full-text search if configured
         if full_text_search and full_text_search.get('enabled') and full_text_search.get('fields'):
@@ -421,7 +429,7 @@ class VectorStoreWrapperBase(BaseToolApiWrapper):
                         for result in text_results:
                             doc_id = result['id']
                             text_score = result['text_score']
-                            
+
                             if doc_id in doc_map:
                                 # Document exists in vector results, combine scores
                                 doc, vector_score = doc_map[doc_id]
