@@ -10,18 +10,17 @@ def get_tools(tool_type, tool):
         # common
         "selected_tools": tool['settings'].get('selected_tools', []),
         "organization_url": tool['settings']['organization_url'],
-        "project": tool['settings'].get('project', None),
-        "token": tool['settings'].get('token', None),
+        "ado_configuration": tool['settings']['ado_configuration'],
         "limit": tool['settings'].get('limit', 5),
         "toolkit_name": tool.get('toolkit_name', ''),
         # indexer settings
-        "llm":tool['settings'].get('llm', None),
-        "connection_string":tool['settings'].get('connection_string', None),
-        "collection_name":str(tool['id']),
-        "doctype":'doc',
-        "embedding_model":"HuggingFaceEmbeddings",
-        "embedding_model_params":{"model_name": "sentence-transformers/all-MiniLM-L6-v2"},
-        "vectorstore_type":"PGVector"
+        "alita": tool['settings'].get('alita', None),
+        "llm": tool['settings'].get('llm', None),
+        "pgvector_configuration": tool['settings'].get('pgvector_configuration', {}),
+        "collection_name": tool['toolkit_name'],
+        "doctype": 'doc',
+        "embedding_model": tool['settings'].get('embedding_model'),
+        "vectorstore_type": "PGVector"
     }
     if tool_type == 'ado_plans':
         return AzureDevOpsPlansToolkit().get_toolkit(**config_dict).get_tools()
