@@ -4,8 +4,10 @@ from langchain_community.agent_toolkits.base import BaseToolkit
 from .api_wrapper import ServiceNowAPIWrapper
 from langchain_core.tools import BaseTool
 from ..base.tool import BaseAction
-from pydantic import create_model, BaseModel, ConfigDict, Field, SecretStr
+from pydantic import create_model, BaseModel, ConfigDict, Field
 from ..utils import clean_string, TOOLKIT_SPLITTER, get_max_toolkit_length
+from ...configurations.service_now import ServiceNowConfiguration
+
 
 name = "service_now"
 
@@ -14,8 +16,7 @@ def get_tools(tool):
         selected_tools=tool['settings'].get('selected_tools', []),
         instance_alias=tool['settings'].get('instance_alias', None),
         base_url=tool['settings']['base_url'],
-        password=tool['settings'].get('password', None),
-        username=tool['settings'].get('username', None),
+        servicenow_configuration=tool['settings']['servicenow_configuration'],
         response_fields=tool['settings'].get('response_fields', None),
         toolkit_name=tool.get('toolkit_name')
     ).get_tools()
@@ -32,14 +33,14 @@ class ServiceNowToolkit(BaseToolkit):
         ServiceNowToolkit.toolkit_max_length = get_max_toolkit_length(selected_tools)
         return create_model(
             name,
-            base_url=(str, Field(description="ServiceNow URL", json_schema_extra={
-                        'max_toolkit_length': ServiceNowToolkit.toolkit_max_length,
-                        'configuration': True,
-                        'configuration_title': True
-                    })),
-            username=(str, Field(description="Username", default=None, json_schema_extra={'configuration': True})),
-            password=(SecretStr, Field(description="Password", default=None, json_schema_extra={'secret': True, 'configuration': True})),
+            name=(str, Field(description="Toolkit name",
+                             json_schema_extra={
+                                 'toolkit_name': True, 'max_toolkit_length': ServiceNowToolkit.toolkit_max_length})),
             response_fields=(Optional[str], Field(description="Response fields", default=None)),
+            servicenow_configuration=(Optional[ServiceNowConfiguration], Field(description="ServiceNow Configuration",
+                                                                               json_schema_extra={
+                                                                                   'configuration_types': [
+                                                                                       'service_now']})),
             selected_tools=(List[Literal[tuple(selected_tools)]],
                             Field(default=[], json_schema_extra={'args_schemas': selected_tools})),
             __config__=ConfigDict(json_schema_extra={
@@ -70,7 +71,12 @@ class ServiceNowToolkit(BaseToolkit):
             selected_tools = []
         if 'response_fields' in kwargs and isinstance(kwargs['response_fields'], str):
             kwargs['fields'] = [field.strip().lower() for field in kwargs['response_fields'].split(',') if field.strip()]
-        servicenow_api_wrapper = ServiceNowAPIWrapper(**kwargs)
+        wrapper_payload = {
+            **kwargs,
+            # TODO use servicenow_configuration fields
+            **kwargs['servicenow_configuration'],
+        }
+        servicenow_api_wrapper = ServiceNowAPIWrapper(**wrapper_payload)
         prefix = clean_string(toolkit_name, cls.toolkit_max_length) + TOOLKIT_SPLITTER if toolkit_name else ''
         available_tools = servicenow_api_wrapper.get_available_tools()
         tools = []
